@@ -20,4 +20,6 @@ pub mod types;
 pub mod functions;
 
 /// π
-pub use core::f32::consts::PI;
\ No newline at end of file
+pub use core::f32::consts::PI;
+/// π / 2.0
+pub use core::f32::consts::FRAC_PI_2;
\ No newline at end of file
